@@ -1,26 +1,21 @@
 import * as React from 'react';
-import { match } from 'react-router';
+import { match as RouteMatch } from 'react-router';
 import { k8sGet } from '@console/internal/module/k8s';
 import { ClusterServiceVersionModel } from '@console/operator-lifecycle-manager';
 import { BreadCrumbs } from '@console/internal/components/utils';
 import { getAnnotations } from '@console/shared/src/selectors/common';
-import { Radio, Title } from '@patternfly/react-core';
+import { RadioGroup } from '@console/internal/components/radio';
 import { InfrastructureModel } from '@console/internal/models';
 import { getRequiredKeys, createDownloadFile } from '../independent-mode/utils';
 import { OCSServiceModel } from '../../models';
-import InstallExternalCluster from '../independent-mode/install';
-import { CreateOCSServiceForm } from './create-form';
-import { OCS_SUPPORT_ANNOTATION } from '../../constants';
+import CreateExternalCluster from '../independent-mode/install';
+import { CreateInternalCluster } from './create-form';
+import { OCS_SUPPORT_ANNOTATION, MODES } from '../../constants';
+import { CreateAttachedDevicesCluster } from './attached-devices/install';
 import './install-page.scss';
 
-enum MODES {
-  CONVERGED = 'Converged',
-  INDEPENDENT = 'Independent',
-}
-
 const INDEP_MODE_SUPPORTED_PLATFORMS = ['Baremetal', 'None', 'VSphere'];
 
-// eslint-disable-next-line no-shadow
 const InstallCluster: React.FC<InstallClusterProps> = ({ match }) => {
   const {
     params: { ns, appName },
@@ -33,10 +28,10 @@ const InstallCluster: React.FC<InstallClusterProps> = ({ match }) => {
     null,
   );
   const [downloadFile, setDownloadFile] = React.useState(null);
-  const [mode, setMode] = React.useState(MODES.CONVERGED);
+  const [mode, setMode] = React.useState(MODES.INTERNAL);
   const [clusterServiceVersion, setClusterServiceVersion] = React.useState(null);
 
-  const handleModeChange = (_checked: boolean, event: React.FormEvent<HTMLInputElement>) => {
+  const handleModeChange = (event: React.FormEvent<HTMLInputElement>) => {
     const { value } = event.currentTarget;
     setMode(value as MODES);
   };
@@ -44,6 +39,7 @@ const InstallCluster: React.FC<InstallClusterProps> = ({ match }) => {
   React.useEffect(() => {
     k8sGet(ClusterServiceVersionModel, appName, ns)
       .then((clusterServiceVersionObj) => {
+        // Todo(bipuladh): Remove this check in 4.7
         const isIndependentSupported = getAnnotations(clusterServiceVersionObj)[
           OCS_SUPPORT_ANNOTATION
         ].includes('external');
@@ -104,47 +100,39 @@ const InstallCluster: React.FC<InstallClusterProps> = ({ match }) => {
           storage, and handles the scenes such as provisioning and management.
         </p>
       </div>
-
-      <div className="co-m-pane__body co-m-pane__form">
-        {isIndependent && isIndepModeSupportedPlatform && (
-          <div className="ceph-install__select-mode">
-            <Title headingLevel="h5" size="lg" className="ceph-install-select-mode__title">
-              Select Mode
-            </Title>
-            <div className="ceph-install-select-mode">
-              <Radio
-                value={MODES.CONVERGED}
-                isChecked={mode === MODES.CONVERGED}
-                onChange={handleModeChange}
-                id="radio-1"
-                className="ceph-install--no-margin"
-                label="Internal"
-                name="converged-mode"
-              />
-            </div>
-            <div className="ceph-install-select-mode">
-              <Radio
-                value={MODES.INDEPENDENT}
-                isChecked={mode === MODES.INDEPENDENT}
-                onChange={handleModeChange}
-                id="radio-2"
-                label="External"
-                name="independent-mode"
-                className="ceph-install--no-margin"
-              />
-            </div>
-          </div>
-        )}
-        {(isIndependent === false || mode === MODES.CONVERGED) && (
-          <CreateOCSServiceForm match={match} />
-        )}
-        {mode === MODES.INDEPENDENT && (
-          <InstallExternalCluster
+      <div className="ceph-install__mode-toggle">
+        <RadioGroup
+          label="Select Mode:"
+          currentValue={mode}
+          inline
+          items={[
+            {
+              value: MODES.INTERNAL,
+              title: MODES.INTERNAL,
+            },
+            {
+              value: MODES.ATTACHED_DEVICES,
+              title: MODES.ATTACHED_DEVICES,
+            },
+            {
+              value: MODES.EXTERNAL,
+              title: MODES.EXTERNAL,
+              disabled: !isIndependent || !isIndepModeSupportedPlatform,
+            },
+          ]}
+          onChange={handleModeChange}
+        />
+      </div>
+      <div>
+        {mode === MODES.INTERNAL && <CreateInternalCluster match={match} />}
+        {mode === MODES.EXTERNAL && (
+          <CreateExternalCluster
             match={match}
             minRequiredKeys={independentReqdKeys}
             downloadFile={downloadFile}
           />
         )}
+        {mode === MODES.ATTACHED_DEVICES && <CreateAttachedDevicesCluster match={match} />}
       </div>
     </>
   );
@@ -153,5 +141,5 @@ const InstallCluster: React.FC<InstallClusterProps> = ({ match }) => {
 export default InstallCluster;
 
 type InstallClusterProps = {
-  match: match<{ ns: string; appName: string }>;
+  match: RouteMatch<{ ns: string; appName: string }>;
 };
