@@ -1,5 +1,5 @@
 import { ValidatedOptions, TextInputTypes, gridItemSpanValueShape } from '@patternfly/react-core';
-import { K8sResourceKind } from '@console/internal/module/k8s';
+import { K8sKind, K8sResourceKind } from '@console/internal/module/k8s';
 
 export interface FieldProps {
   name: string;
@@ -43,6 +43,7 @@ export enum GroupTextType {
 export interface CheckboxFieldProps extends FieldProps {
   formLabel?: string;
   value?: string;
+  onChange?: (val: boolean) => void;
 }
 
 export interface SearchInputFieldProps extends BaseInputFieldProps {
@@ -85,6 +86,7 @@ export interface MultiColumnFieldProps extends FieldProps {
 export interface YAMLEditorFieldProps extends FieldProps {
   onChange?: (value: string) => void;
   onSave?: () => void;
+  schemaModel?: K8sKind;
 }
 
 export interface NameValuePair {
@@ -112,18 +114,33 @@ export interface SecretKeyRef {
 }
 
 export interface RadioButtonFieldProps extends FieldProps {
-  value: string | number;
+  value: React.ReactText;
   description?: React.ReactNode;
+  onChange?: (value: React.ReactText) => void;
 }
 
 export interface RadioGroupFieldProps extends FieldProps {
+  isInline?: boolean;
   options: RadioGroupOption[];
+  onChange?: (value: React.ReactText) => void;
 }
 
 export interface RadioGroupOption {
-  value: string | number;
+  value: React.ReactText;
   label: React.ReactNode;
   isDisabled?: boolean;
   children?: React.ReactNode;
   activeChildren?: React.ReactElement;
 }
+
+export interface SelectInputOption {
+  value: string;
+  disabled: boolean;
+}
+
+export interface SelectInputFieldProps extends FieldProps {
+  options: SelectInputOption[];
+  placeholderText?: React.ReactNode;
+  isCreatable?: boolean;
+  hasOnCreateOption?: boolean;
+}
