@@ -6,14 +6,4 @@ export const getImageForCSVIcon = (icon: CSVIcon | undefined) => {
   return icon ? `data:${icon.mediatype};base64,${icon.base64data}` : operatorLogo;
 };
 
-export const isIconUrl = (url: string): boolean => {
-  try {
-    // eslint-disable-next-line no-new
-    new URL(url);
-    return true;
-  } catch {
-    return false;
-  }
-};
-
 export const getDefaultOperatorIcon = () => operatorLogo;
