@@ -1,5 +1,6 @@
 import * as React from 'react';
 import * as _ from 'lodash';
+import * as classNames from 'classnames';
 import {
   DeploymentConfigModel,
   DeploymentModel,
@@ -8,12 +9,15 @@ import {
   ReplicationControllerModel,
   ReplicaSetModel,
   PodModel,
+  JobModel,
+  CronJobModel,
 } from '@console/internal/models';
 import { ChartLabel } from '@patternfly/react-charts';
 import {
   K8sResourceKind,
   K8sKind,
   SelfSubjectAccessReviewKind,
+  HorizontalPodAutoscalerKind,
 } from '@console/internal/module/k8s';
 import { useSafetyFirst } from '@console/internal/components/safety-first';
 import { PodRCData, PodRingResources, PodRingData, ExtPodKind } from '../types';
@@ -64,8 +68,8 @@ const applyPods = (podsData: PodRingData, dc: PodRCData) => {
   return podsData;
 };
 
-const pluralizeString = (count: number, singularString: string, expectedString?: string) =>
-  count && count > 1 ? expectedString || `${singularString}s` : singularString;
+const podKindString = (count: number) =>
+  (count === 1 ? PodModel.label : PodModel.plural).toLowerCase();
 
 const isPendingPods = (
   pods: ExtPodKind[],
@@ -95,11 +99,13 @@ const getTitleAndSubtitle = (
 ) => {
   let titlePhrase;
   let subTitlePhrase = '';
+  let longTitle = false;
   let longSubtitle = false;
 
   // handles the initial state when the first pod is coming up and the state for no pods(scaled to zero)
   if (!currentPodCount) {
     titlePhrase = isPending ? '0' : `Scaled to 0`;
+    longTitle = !isPending;
     if (desiredPodCount) {
       subTitlePhrase = `scaling to ${desiredPodCount}`;
       longSubtitle = true;
@@ -110,24 +116,32 @@ const getTitleAndSubtitle = (
   if (currentPodCount) {
     titlePhrase = currentPodCount.toString();
     if (currentPodCount === desiredPodCount) {
-      subTitlePhrase = pluralizeString(currentPodCount, 'pod');
+      subTitlePhrase = podKindString(currentPodCount);
     } else {
       subTitlePhrase = `scaling to ${desiredPodCount}`;
       longSubtitle = true;
     }
   }
 
-  return { title: titlePhrase, subTitle: subTitlePhrase, longSubtitle };
+  return { title: titlePhrase, longTitle, subTitle: subTitlePhrase, longSubtitle };
 };
 
-const getTitleComponent = (longSubtitle: boolean = false, reversed: boolean = false) =>
-  React.createElement(ChartLabel, {
+const getTitleComponent = (
+  longTitle: boolean = false,
+  longSubtitle: boolean = false,
+  reversed: boolean = false,
+) => {
+  const labelClasses = classNames('pf-chart-donut-title', {
+    'pod-ring__center-text--reversed': reversed,
+    'pod-ring__center-text': !reversed,
+    'pod-ring__long-text': longTitle,
+  });
+  return React.createElement(ChartLabel, {
     dy: longSubtitle ? -5 : 0,
     style: { lineHeight: '11px' },
-    className: `pf-chart-donut-title ${
-      reversed ? 'pod-ring__center-text--reversed' : 'pod-ring__center-text'
-    }`,
+    className: labelClasses,
   });
+};
 
 export const podRingLabel = (
   obj: K8sResourceKind,
@@ -151,7 +165,7 @@ export const podRingLabel = (
       return {
         title: titleData.title,
         subTitle: titleData.subTitle,
-        titleComponent: getTitleComponent(titleData.longSubtitle),
+        titleComponent: getTitleComponent(titleData.longTitle, titleData.longSubtitle),
       };
     case RevisionModel.kind:
       currentPodCount = (obj.status?.readyReplicas || 0) + failedPodCount;
@@ -163,7 +177,7 @@ export const podRingLabel = (
         return {
           title,
           subTitle,
-          titleComponent: getTitleComponent(false, true),
+          titleComponent: getTitleComponent(false, false, true),
         };
       }
       if (isPending) {
@@ -171,13 +185,26 @@ export const podRingLabel = (
         subTitle = `scaling to ${desiredPodCount}`;
       } else {
         title = currentPodCount;
-        subTitle = pluralizeString(currentPodCount, 'pod');
+        subTitle = podKindString(currentPodCount);
       }
       return {
         title,
         subTitle,
         titleComponent: getTitleComponent(),
       };
+    case PodModel.kind:
+    case JobModel.kind:
+      return {
+        title: '1',
+        subTitle: PodModel.label,
+        titleComponent: getTitleComponent(),
+      };
+    case CronJobModel.kind:
+      return {
+        title: `${pods.length}`,
+        subTitle: podKindString(currentPodCount),
+        titleComponent: getTitleComponent(),
+      };
     default:
       currentPodCount = (obj.status?.readyReplicas || 0) + failedPodCount;
       desiredPodCount = obj.spec?.replicas;
@@ -186,11 +213,28 @@ export const podRingLabel = (
       return {
         title: titleData.title,
         subTitle: titleData.subTitle,
-        titleComponent: getTitleComponent(titleData.longSubtitle),
+        titleComponent: getTitleComponent(titleData.longTitle, titleData.longSubtitle),
       };
   }
 };
 
+export const hpaPodRingLabel = (
+  obj: K8sResourceKind,
+  hpa: HorizontalPodAutoscalerKind,
+  pods: ExtPodKind[],
+): PodRingLabelType => {
+  const desiredPodCount = obj.spec?.replicas;
+  const desiredPods = hpa.status?.desiredReplicas || desiredPodCount;
+  const currentPods = hpa.status?.currentReplicas;
+  const scaling =
+    (!currentPods && !!desiredPods) || !pods.every((p) => p.status?.phase === 'Running');
+  return {
+    title: scaling ? 'Autoscaling' : 'Autoscaled',
+    subTitle: `to ${desiredPods}`,
+    titleComponent: getTitleComponent(false, false, true),
+  };
+};
+
 export const usePodScalingAccessStatus = (
   obj: K8sResourceKind,
   resourceKind: K8sKind,
