@@ -1,19 +1,24 @@
 import * as React from 'react';
-import { CheckboxField, EnvironmentField } from '../../formik-fields';
+import * as _ from 'lodash';
+import { CheckboxField, EnvironmentField } from '@console/shared';
+import { K8sResourceKind } from '@console/internal/module/k8s';
+import { getStrategyType } from '@console/internal/components/build';
 import FormSection from '../section/FormSection';
 
 export interface BuildConfigSectionProps {
   namespace: string;
+  resource?: K8sResourceKind;
 }
 
-const BuildConfigSection: React.FC<BuildConfigSectionProps> = ({ namespace }) => {
-  const buildConfigObj = {
+const BuildConfigSection: React.FC<BuildConfigSectionProps> = ({ namespace, resource }) => {
+  const buildConfigObj = resource || {
     kind: 'BuildConfig',
     metadata: {
       namespace,
     },
   };
-
+  const strategyType = getStrategyType(resource?.spec?.strategy?.type);
+  const envs = _.get(buildConfigObj, `spec.strategy.${strategyType}.env`, []);
   return (
     <FormSection title="Build Configuration" fullWidth>
       <CheckboxField name="build.triggers.webhook" label="Configure a webhook build trigger" />
@@ -29,6 +34,7 @@ const BuildConfigSection: React.FC<BuildConfigSectionProps> = ({ namespace }) =>
         name="build.env"
         label="Environment Variables (Build and Runtime)"
         obj={buildConfigObj}
+        envs={envs}
         envPath={['spec', 'strategy']}
       />
     </FormSection>
