@@ -219,7 +219,7 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
   };
   const conflictingProvidedAPIs = (ns: string) => {
     const operatorGroups = props.operatorGroup.data.filter(
-      (og) => og.status.namespaces.includes(ns) || isGlobal(og),
+      (og) => og.status?.namespaces?.includes(ns) || isGlobal(og),
     );
     if (_.isEmpty(operatorGroups)) {
       return [];
@@ -280,7 +280,7 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
       subjects: [
         {
           kind: 'ServiceAccount',
-          name: 'prometheus-operator',
+          name: 'prometheus-k8s',
           namespace: 'openshift-monitoring',
         },
       ],
