@@ -2,6 +2,7 @@ import * as _ from 'lodash-es';
 import * as React from 'react';
 import { render } from 'react-dom';
 import { Helmet } from 'react-helmet';
+import { linkify } from 'react-linkify';
 import { Provider } from 'react-redux';
 import { Route, Router, Switch } from 'react-router-dom';
 // AbortController is not supported in some older browser versions
@@ -13,13 +14,22 @@ import { getBrandingDetails, Masthead } from './masthead';
 import { ConsoleNotifier } from './console-notifier';
 import { ConnectedNotificationDrawer } from './notification-drawer';
 import { Navigation } from './nav';
-import { history } from './utils';
+import { history, AsyncComponent } from './utils';
 import * as UIActions from '../actions/ui';
 import { fetchSwagger, getCachedResources } from '../module/k8s';
 import { receivedResources, watchAPIServices } from '../actions/k8s';
 // cloud shell imports must come later than features
 import CloudShell from '@console/app/src/components/cloud-shell/CloudShell';
 import CloudShellTab from '@console/app/src/components/cloud-shell/CloudShellTab';
+import DetectPerspective from '@console/app/src/components/detect-perspective/DetectPerspective';
+import { withExtensions, isContextProvider } from '@console/plugin-sdk';
+import { GuidedTour } from '@console/app/src/components/tour';
+
+const consoleLoader = () =>
+  import(
+    '@console/kubevirt-plugin/src/components/connected-vm-console/vm-console-page' /* webpackChunkName: "kubevirt" */
+  ).then((m) => m.VMConsolePage);
+import QuickStartDrawer from '@console/app/src/components/quick-starts/QuickStartDrawer';
 import '../vendor.scss';
 import '../style.scss';
 
@@ -28,11 +38,19 @@ import { Page } from '@patternfly/react-core';
 
 const breakpointMD = 768;
 const NOTIFICATION_DRAWER_BREAKPOINT = 1800;
-
 // Edge lacks URLSearchParams
 import 'url-search-params-polyfill';
 
-class App extends React.PureComponent {
+// Disable linkify 'fuzzy links' across the app.
+// Only linkify url strings beginning with a proper protocol scheme.
+linkify.set({ fuzzyLink: false });
+
+const EnhancedProvider = ({ Provider: ContextProvider, useValueHook, children }) => {
+  const value = useValueHook();
+  return <ContextProvider value={value}>{children}</ContextProvider>;
+};
+
+class App_ extends React.PureComponent {
   constructor(props) {
     super(props);
 
@@ -124,36 +142,56 @@ class App extends React.PureComponent {
 
   render() {
     const { isNavOpen, isDrawerInline } = this.state;
+    const { contextProviderExtensions } = this.props;
     const { productName } = getBrandingDetails();
 
-    return (
+    const content = (
       <>
         <Helmet titleTemplate={`%s · ${productName}`} defaultTitle={productName} />
-        <ConsoleNotifier location="BannerTop" />
-        <Page
-          header={<Masthead onNavToggle={this._onNavToggle} />}
-          sidebar={
-            <Navigation
-              isNavOpen={isNavOpen}
-              onNavSelect={this._onNavSelect}
-              onPerspectiveSelected={this._onNavSelect}
-            />
-          }
-        >
-          <ConnectedNotificationDrawer
-            isDesktop={isDrawerInline}
-            onDrawerChange={this._onNotificationDrawerToggle}
+        <QuickStartDrawer>
+          <ConsoleNotifier location="BannerTop" />
+          <Page
+            header={<Masthead onNavToggle={this._onNavToggle} />}
+            sidebar={
+              <Navigation
+                isNavOpen={isNavOpen}
+                onNavSelect={this._onNavSelect}
+                onPerspectiveSelected={this._onNavSelect}
+              />
+            }
           >
-            <AppContents />
-          </ConnectedNotificationDrawer>
-        </Page>
-        <CloudShell />
-        <ConsoleNotifier location="BannerBottom" />
+            <ConnectedNotificationDrawer
+              isDesktop={isDrawerInline}
+              onDrawerChange={this._onNotificationDrawerToggle}
+            >
+              <AppContents />
+            </ConnectedNotificationDrawer>
+          </Page>
+          <div id="modal-container" />
+          <CloudShell />
+          <GuidedTour />
+          <ConsoleNotifier location="BannerBottom" />
+        </QuickStartDrawer>
       </>
     );
+
+    return (
+      <DetectPerspective>
+        {contextProviderExtensions.reduce(
+          (children, e) => (
+            <EnhancedProvider key={e.uid} {...e.properties}>
+              {children}
+            </EnhancedProvider>
+          ),
+          content,
+        )}
+      </DetectPerspective>
+    );
   }
 }
 
+const App = withExtensions({ contextProviderExtensions: isContextProvider })(App_);
+
 const startDiscovery = () => store.dispatch(watchAPIServices());
 
 // Load cached API resources from localStorage to speed up page load.
@@ -176,11 +214,16 @@ setInterval(() => store.dispatch(UIActions.updateTimestamps(Date.now())), 10000)
 fetchSwagger();
 
 // Used by GUI tests to check for unhandled exceptions
-window.windowError = false;
-window.onerror = window.onunhandledrejection = (e) => {
+window.windowError = null;
+window.onerror = (message, source, lineno, colno, error) => {
   // eslint-disable-next-line no-console
-  console.error('Uncaught error', e);
-  window.windowError = e || true;
+  console.error('Uncaught error', error);
+  window.windowError = error;
+};
+window.onunhandledrejection = (promiseRejectionEvent) => {
+  // eslint-disable-next-line no-console
+  console.error('Unhandled promise rejection', promiseRejectionEvent);
+  window.windowError = promiseRejectionEvent;
 };
 
 if ('serviceWorker' in navigator) {
@@ -215,6 +258,10 @@ render(
   <Provider store={store}>
     <Router history={history} basename={window.SERVER_FLAGS.basePath}>
       <Switch>
+        <Route
+          path="/k8s/ns/:ns/virtualmachineinstances/:name/standaloneconsole"
+          render={(componentProps) => <AsyncComponent loader={consoleLoader} {...componentProps} />}
+        />
         <Route path="/terminal" component={CloudShellTab} />
         <Route path="/" component={App} />
       </Switch>
